with Ada.Unchecked_Deallocation;

package Scrabble_Types is

   --  Definition of the weights (english scrabble) given to each letter.
   subtype Small_Letters is Character range 'a' .. 'z';
   Weights : array (Small_Letters'Range) of Positive :=
     ('q' => 10, 'z' => 10,
      'j' => 8, 'x' => 8,
      'k' => 5,
      'f' => 4, 'h' => 4, 'v' => 4, 'w' => 4, 'y' => 4,
      'b' => 3, 'c' => 3, 'm' => 3, 'p' => 3,
      'd' => 2, 'g' => 2,
      others => 1);  --  "esarintulo" : 10 letters to 1 point each.

   --  Definition of a reference type for the ada standard String type.
   type String_Ref is access all String;

   --  This procedure allows to free the memory space pointed by the ref.
   --  Example: if you have a variable of type String_Ref called My_String,
   --  call Free (My_String) to free the memory (then My_String is null).
   procedure Free is new Ada.Unchecked_Deallocation (String, String_Ref);
   ------------------------------------------------------------------------

end Scrabble_Types;
